=======
Credits
=======

Development Lead
----------------

* Adrian Likins <@alikins>
* Chris Houseknecht <@chouseknecht>
* Alexander Saprykin <@cutwater>

Based on
--------

ansible-galaxy from `<https://github.com/ansible/ansible>`

